# UPiano

A Piano in your terminal.

Powered by:

* [Python](https://www.python.org)
* [Textual](https://textual.textualize.io/)
* [FluidSynth](https://github.com/FluidSynth/fluidsynth)
* [pyFluidSynth](https://github.com/nwhitehead/pyfluidsynth)

Made with ❤️  by Elias Dorneles
